Module: StandardId::PasswordlessFlow
- Extended by:
- ActiveSupport::Concern
- Includes:
- PasswordlessStrategy
- Defined in:
- app/controllers/concerns/standard_id/passwordless_flow.rb
Overview
Public concern for host app controllers that need passwordless OTP capabilities.
Include this in your custom controllers to generate and verify OTP codes without mounting the WebEngine’s built-in login controllers.
Requires the including controller to have access to ‘request` (standard in all Rails controllers). No other dependencies are needed – both `generate_passwordless_otp` and `verify_passwordless_otp` only use `request`.