Module: StandardId::SentryContext
- Extended by:
- ActiveSupport::Concern
- Defined in:
- app/controllers/concerns/standard_id/sentry_context.rb
Overview
Sets Sentry user context from the current authenticated account.
This is a standalone concern that host apps can include in their ApplicationController to automatically set Sentry user context for each request. It eliminates the need for apps to write their own SentryContext boilerplate.
Safe to include even when the Sentry gem is not installed – the callback is a no-op if ‘Sentry` is not defined.